# Haltia.AI Software Development Kit (SDK) for Python

[![License](https://img.shields.io/badge/license-Public%20Domain-blue.svg)](https://unlicense.org)
[![Compatibility](https://img.shields.io/badge/python-3.9%2B-blue)](https://pypi.org/project/haltia/)
[![Package](https://img.shields.io/pypi/v/haltia)](https://pypi.org/project/haltia/)

## Prerequisites

- [Python](https://python.org) 3.9+

- [Haltia.AI SDK](https://sdk.haltia.ai) 24.0+

## Installation

```shell
$ pip install haltia
```

## Examples

### Importing the library

```python
from haltia import sdk
```
